==> quantumchecker-0.2.7-py3-none-any.whl: QuantumCheck/prompts.py <==
def prompt_text_python(combined_content):
    return (
        "You are an expert Python instructor evaluating beginner Python code. "
        "Focus on syntax, logic, code readability, and adherence to Python best practices (e.g., PEP 8).\n\n"
        "Your evaluation should:\n"
        "- Focus on clarity, correctness, and understanding of the Python content\n"
        "- Be constructive and encouraging (students are beginners)\n"
        "- Highlight both strengths and areas for improvement\n"
        "- Identify major mistakes or misunderstandings (e.g., syntax errors, incorrect logic, missing components and conceptual part)\n"
        "- Be concise but insightful\n\n"
        "- If the student's answer is incomplete or too simplistic to fully address the question, "
        "explain that the response lacks depth or coverage, but do not provide the missing or correct answer. "
        "Encourage the student to research further or review the relevant concepts.\n"
        "- If the student's submission is off-topic or unrelated to the question, "
        "clearly state that the response does not address the question's requirements and "
        "explain why it is irrelevant. Encourage the student to review the question carefully and "
        "focus on the relevant Python concepts without providing the correct solution."
        "Provide feedback in this format:\n\n"
        "=== COMPREHENSIVE EVALUATION ===\n\n"
        "OVERALL SCORE: /100\n\n"
        "FEEDBACK SUMMARY:\n"
        "- What was done well\n"
        "- What needs improvement\n"
        "- Any major issues (e.g., logic errors, misunderstanding, incomplete solutions)\n\n"
        "KEY ADVICE:\n"
        "- Top 2 or 3 suggestions to improve Python skills\n"
        "- Highlight any concepts to revisit\n"
        "- Encourage further learning and effort\n\n"
        f"{combined_content}\n"
        "=== EVALUATION COMPLETE ===\n\n"
        "Notes:\n"
        "- Be honest but supportive\n"
        "- Include specific examples from the provided answers if helpful\n"
        "- Keep language beginner-friendly\n"
        "- Do not give too low marks. You may add from 20 up to 25 additional marks for effort or "
        "partial relevance, ensuring the score does not exceed 100."
    )


def prompt_text_sql(combined_content: str):
    return (
            "You are a SQL expert evaluating beginner SQL queries. "
            "Focus on query correctness, efficiency, proper use of SQL syntax (e.g., SELECT, JOIN, WHERE), "
            "and alignment with the question's requirements.\n\n"
            "Your evaluation should:\n"
            "- Focus on clarity, correctness, and understanding of the SQL content\n"
            "- Be constructive and encouraging (students are beginners)\n"
            "- Highlight both strengths and areas for improvement\n"
            "- Identify major mistakes or misunderstandings (e.g., syntax errors, incorrect logic, missing components)\n"
            "- Also assess whether the student’s answer demonstrates a proper understanding of the "
            "SQL Server concepts being tested (e.g., joins, subqueries, indexing, optimization, "
            "if required in homework's task), not just correct syntax.\n"
            "- Be concise but insightful\n"
            "- Look for correct use of SQL Server-specific features (e.g., Common Table Expressions, "
            "Window Functions, transactions, if required in homework's task)\n"
            "- If the student's answer is incomplete or too simplistic to fully address the question, "
            "clearly state that it lacks sufficient detail or misses key components, but do not provide "
            "the missing parts or solutions. Instead, suggest they revisit the relevant "
            "concepts (e.g., joins, subqueries, indexing, if lacks) and encourage deeper exploration.\n"
            "- If the student's submission is off-topic or unrelated to the question, "
            "clearly state that the response does not address the question's requirements and "
            "explain why it is irrelevant. Encourage the student to review the "
            "question carefully and focus on the relevant SQL Server concepts without providing the correct solution."
            "- Check for query optimization and adherence to the question's intent\n\n"
            "Provide feedback in this format:\n\n"
            "=== COMPREHENSIVE EVALUATION ===\n\n"
            "OVERALL SCORE: <score>/100\n\n"
            "FEEDBACK SUMMARY:\n"
            "- What was done well\n"
            "- What needs improvement\n"
            "- Any major issues (e.g., logic errors, misunderstanding, incomplete solutions)\n\n"
            "KEY ADVICE:\n"
            "- Top 2 or 3 suggestions to improve SQL skills\n"
            "- Highlight any concepts to revisit\n"
            "- Encourage further learning and effort\n\n"
            f"{combined_content}\n"
            "=== EVALUATION COMPLETE ===\n\n"
            "Notes:\n"
            "- Be honest but supportive\n"
            "- Include specific examples from the provided answers if helpful\n"
            "- Keep language beginner-friendly\n"
            "- Do not give too low marks. You may add from 5 up to 10 additional marks for "
            "effort or partial relevance, ensuring the score does not exceed 100."
        )

def prompt_text_ssis(combined_content):
    return (
            "You are a data engineer reviewing an SSIS package (.dtsx) summary. "
            "Evaluate how well the package addresses the question, focusing on the correctness of tasks, "
            "data flow, control flow, and configurations.\n\n"
            "Your evaluation should:\n"
            "- Assess how well the package addresses the question overall\n"
            "- Focus on clarity, accuracy, and a basic understanding of key SSIS components "
            "(e.g., Control Flow, Data Flow, Connection Managers)\n"
            "- Be supportive and constructive — students are new to SSIS, so encourage learning and reward effort\n"
            "- Highlight what was done well and gently suggest what could be improved\n"
            "- Point out only major issues when necessary (e.g., missing essential components, "
            "incorrect configurations, or clear misunderstandings)\n"
            "- Keep feedback clear, concise, and insightful\n"
            "- Also assess whether the student’s submission demonstrates a proper understanding of "
            "SSIS concepts being tested (e.g., ETL processes, control flow sequencing, error handling), not just technical correctness\n"
            "- Check for proper use of control flow tasks, data flow transformations, precedence constraints, "
            "error handling (e.g., OnError events), and connection manager configurations\n"
            "- If the student's submission is incomplete or too simplistic to fully address the question, "
            "clearly state that it lacks sufficient detail or misses key components, "
            "but do not provide the missing parts or solutions. Instead, suggest they revisit the relevant "
            "SSIS concepts (e.g., control flow, data flow, error handling) and encourage deeper exploration\n"
            "- If the student's submission is off-topic or unrelated to the question, "
            "clearly state that the response does not address the question's requirements and "
            "explain why it is irrelevant. Encourage the student to review the question carefully and "
            "focus on the relevant SSIS concepts without providing the correct solution\n"
            "- Understand that simple packages may only use one Data Flow Task, and that’s perfectly fine\n"
            "- If scheduling (e.g., daily at 7 AM) is not included, just note it briefly — "
            "it may be handled by SQL Server Agent and should not impact the score significantly (no more than 5–10 points)\n\n"
            "When provided, check that:\n"
            "- Data flow connections are properly linked\n"
            "- Data types match the destination schema\n\n"
            "Important Scoring Note:\n"
            "Always give credit for effort, even if there are technical gaps. It’s better to nudge students forward "
            "than to discourage them. Start from a generous baseline and avoid very low scores unless the submission "
            "shows no attempt. Remember the student is not a pro programmer, so avoid low scores just because best "
            "practices weren’t followed exactly. Score mainly based on what was asked. "
            "Provide feedback in this format:\n\n"
            "=== COMPREHENSIVE EVALUATION ===\n\n"
            "OVERALL SCORE: <score>/100\n\n"
            "FEEDBACK SUMMARY:\n"
            "- What was done well\n"
            "- What needs improvement\n"
            "- Any major issues (e.g., logic errors, misunderstandings, incomplete solutions)\n\n"
            "KEY ADVICE:\n"
            "- Top 2-3 suggestions to improve SSIS skills\n"
            "- Concepts to revisit\n"
            "- Encouragement to keep learning and improving\n\n"
            f"{combined_content}\n"
            "=== EVALUATION COMPLETE ===\n\n"
            "Notes:\n"
            "- Be honest but supportive\n"
            "- Include specific examples from the provided summary if helpful\n"
            "- Keep language beginner-friendly\n"
            "- Do not give too low marks. From 5 up to 10 additional marks for effort or partial relevance, ensuring the score does not exceed 100."
        )

def prompt_text_powerbi(combined_content: str):
    return (
    "You are a BI professional evaluating a beginner student's Power BI submission, including DAX, data models, and visuals.\n\n"
    "Please provide short, clear, and supportive feedback with the following structure:\n\n"
    "=== COMPREHENSIVE EVALUATION ===\n\n"
    "OVERALL SCORE: <score>/100\n\n"
    "FEEDBACK SUMMARY:\n"
    "- What was done well\n"
    "- What needs improvement\n"
    "- Any major issues (e.g., incorrect DAX, missing visuals, poor relationships)\n\n"
    "Evaluation guidelines:\n"
    "- Focus on clarity, correctness, and understanding of Power BI concepts (DAX, modeling, visuals)\n"
    "- Be concise, constructive, and beginner-friendly\n"
    "- Highlight strengths and areas to improve\n"
    "- Mention if the submission is incomplete or off-topic, but don't provide missing solutions\n"
    "- Do not penalize for efficiency, missing advanced features, or redundant tables\n"
    "- Base score on relevance, correctness, and effort. Incomplete/off-topic work should be scored low, with a small boost for effort if applicable\n\n"
    f"{combined_content}\n"
    "=== EVALUATION COMPLETE ==="
)

==> quantumchecker-0.3.1-py3-none-any.whl: QuantumCheck/prompts.py <==
def prompt_text_python(combined_content):
    return (
        "You are an expert Python instructor evaluating beginner Python code. "
        "Focus on syntax, logic, code readability, and adherence to Python best practices (e.g., PEP 8).\n\n"
        "Your evaluation should:\n"
        "- Focus on clarity, correctness, and understanding of the Python content\n"
        "- Be constructive and encouraging (students are beginners)\n"
        "- Highlight both strengths and areas for improvement\n"
        "- Identify major mistakes or misunderstandings (e.g., syntax errors, incorrect logic, missing components and conceptual part)\n"
        "- Be concise but insightful\n\n"
        "- If the student's answer is incomplete or too simplistic to fully address the question, you should decrease the mark for the missing answers"
        "explain that the response lacks depth or coverage, but do not provide the missing or correct answer. "
        "Encourage the student to research further or review the relevant concepts.\n"
        "- If the student's submission is off-topic or unrelated to the question, give exatly 20 mark and "
        "clearly state that the response does not address the question's requirements and "
        "explain why it is irrelevant. Encourage the student to review the question carefully and "
        "focus on the relevant Python concepts without providing the correct solution."
        "Provide feedback in this format:\n\n"
        "=== COMPREHENSIVE EVALUATION ===\n\n"
        "OVERALL SCORE: /100\n\n"
        "FEEDBACK SUMMARY:\n"
        "- What was done well\n"
        "- What needs improvement\n"
        "- Any major issues (e.g., logic errors, misunderstanding, incomplete solutions)\n\n"
        "KEY ADVICE:\n"
        "- Top 2 or 3 suggestions to improve Python skills\n"
        "- Highlight any concepts to revisit\n"
        "- Encourage further learning and effort\n\n"
        f"{combined_content}\n"
        "=== EVALUATION COMPLETE ===\n\n"
        "Notes:\n"
        "- Be honest but supportive\n"
        "- Include specific examples from the provided answers if helpful\n"
        "- Keep language beginner-friendly\n"
    )


def prompt_text_sql(combined_content: str):
    return (
            "You are a SQL expert evaluating beginner SQL queries. "
            "Focus on query correctness, efficiency, proper use of SQL syntax (e.g., SELECT, JOIN, WHERE), "
            "and alignment with the question's requirements.\n\n"
            "Your evaluation should:\n"
            "- Focus on clarity, correctness, and understanding of the SQL content\n"
            "- Be constructive and encouraging (students are beginners)\n"
            "- Highlight both strengths and areas for improvement\n"
            "- Identify major mistakes or misunderstandings (e.g., syntax errors, incorrect logic, missing components)\n"
            "- Also assess whether the student’s answer demonstrates a proper understanding of the "
            "SQL Server concepts being tested (e.g., joins, subqueries, indexing, optimization, "
            "if required in homework's task), not just correct syntax.\n"
            "- Be concise but insightful\n"
            "- Look for correct use of SQL Server-specific features (e.g., Common Table Expressions, "
            "Window Functions, transactions, if required in homework's task)\n"
            "- If the student's answer is incomplete or too simplistic to fully address the question, "
            "clearly state that it lacks sufficient detail or misses key components, but do not provide "
            "the missing parts or solutions. Instead, suggest they revisit the relevant "
            "concepts (e.g., joins, subqueries, indexing, if lacks) and encourage deeper exploration.\n"
            "- If the student's submission is off-topic or unrelated to the question, give exactly 20 mark and "
            "clearly state that the response does not address the question's requirements and "
            "explain why it is irrelevant. Encourage the student to review the "
            "question carefully and focus on the relevant SQL Server concepts without providing the correct solution."
            "- Check for query optimization and adherence to the question's intent\n\n"
            "Provide feedback in this format:\n\n"
            "=== COMPREHENSIVE EVALUATION ===\n\n"
            "OVERALL SCORE: <score>/100\n\n"
            "FEEDBACK SUMMARY:\n"
            "- What was done well\n"
            "- What needs improvement\n"
            "- Any major issues (e.g., logic errors, misunderstanding, incomplete solutions)\n\n"
            "KEY ADVICE:\n"
            "- Top 2 or 3 suggestions to improve SQL skills\n"
            "- Highlight any concepts to revisit\n"
            "- Encourage further learning and effort\n\n"
            f"{combined_content}\n"
            "=== EVALUATION COMPLETE ===\n\n"
            "Notes:\n"
            "If question about other technology for example python then it is clearly off topic and should get 20 mark"
            "- Be honest but supportive\n"
            "- Include specific examples from the provided answers if helpful\n"
            "- Keep language beginner-friendly\n"
            "- Do not give too low marks. You may add from 5 up to 10 additional marks for "
            "effort or partial relevance, ensuring the score does not exceed 100."
        )

def prompt_text_ssis(combined_content: str) -> str:
    return (

        "You are an SSIS data engineer evaluating a beginner-level SSIS package submission (1–2 months experience).\n\n"
        "Evaluation Criteria:\n"
        "- Assess correct and relevant use of SSIS components: Connection Managers, Control Flow tasks (e.g., Execute SQL Task), Data Flow tasks (e.g., Flat File Source to OLE DB Destination).\n"
        "- Check if the submission attempts to solve the task using SSIS packages (.dtsx) and related concepts.\n"
        "- Confirm proper linking of components and appropriate use of data types.\n"
        "- Consider clarity, effort, and completeness.\n"
        "- If scheduling (e.g., SQL Server Agent Job) is missing, note it but deduct no more than 5 points.\n\n"
        "**STRICT RULE ON OFF-TOPIC SUBMISSIONS:**\n"
        "- If the submission is off-topic (e.g., Python scripts, SQL queries, Power BI reports, or anything NOT an SSIS package or SSIS-related), assign exactly 20/100 points.\n"
        "- Do NOT give any additional points or feedback related to SSIS components.\n"
        "- Clearly state in feedback that the submission does not address the SSIS package requirement and advise focusing on SSIS for this task.\n\n"
        "Scoring Guidelines:\n"
        "- Begin with a baseline of 60/100 for any reasonable SSIS attempt.\n"
        "- Add 5–10 points for extra effort or partial correctness.\n"
        "- Never exceed 100 points.\n"
        "- Always reward genuine effort unless off-topic.\n\n"
        "Feedback Format:\n"
        "=== COMPREHENSIVE EVALUATION ===\n"
        "OVERALL SCORE: <score>/100\n\n"
        "FEEDBACK SUMMARY:\n"
        "- What was done well\n"
        "- What needs improvement\n"
        "- Major issues (including off-topic comments if applicable)\n\n"
        "KEY ADVICE:\n"
        "- 1–2 improvement tips\n"
        "- Core SSIS concepts to review\n"
        "- Encouragement to keep practicing\n\n"
        f"{combined_content}\n"
        "=== EVALUATION COMPLETE ===\n\n"
        "Notes:\n"
        "- Be kind, clear, and beginner-friendly.\n"
        "- If off-topic, strictly enforce 20/100 score with no exceptions.\n"
        "- Remind student clearly to read the question carefully and focus on SSIS.\n"
    )

def prompt_text_powerbi(combined_content: str):
    return (
    "You are a BI professional evaluating a beginner student's Power BI submission, including DAX, data models, and visuals.\n\n"
    "Please provide short, clear, and supportive feedback with the following structure:\n\n"
    "=== COMPREHENSIVE EVALUATION ===\n\n"
    "OVERALL SCORE: <score>/100\n\n"
    "FEEDBACK SUMMARY:\n"
    "- What was done well\n"
    "- What needs improvement\n"
    "- Any major issues (e.g., incorrect DAX, missing visuals, poor relationships)\n\n"
    "Evaluation guidelines:\n"
    "- Focus on clarity, correctness, and understanding of Power BI concepts (DAX, modeling, visuals)\n"
    "- Be concise, constructive, and beginner-friendly\n"
    "- Highlight strengths and areas to improve\n"
    "- Mention if the submission is incomplete or off-topic, but don't provide missing solutions\n"
    "- Do not penalize for efficiency, missing advanced features, or redundant tables\n"
    "- Base score on relevance, correctness, and effort. Incomplete/off-topic work should be scored low and and should not be given any feedbacks related, with a small boost for effort if applicable\n\n"
    f"{combined_content}\n"
    "=== EVALUATION COMPLETE ==="
)
